@@ -1,4 +1,5 @@
 # SPDX-FileCopyrightText: 2018 Scott Shawcroft for Adafruit Industries
+# SPDX-FileCopyrightText: 2022 Matt Land
 #
 # SPDX-License-Identifier: MIT
 
@@ -8,22 +9,42 @@
 
 Load pixel values (indices or colors) into a bitmap and colors into a palette.
 
-* Author(s): Scott Shawcroft
+* Author(s): Scott Shawcroft, Matt Land
 
 """
 # pylint: disable=import-outside-toplevel
 
+try:
+    from typing import (
+        Tuple,
+        Iterator,
+        Optional,
+        List,
+        Iterable,
+        Union,
+    )
+    from io import BufferedReader
+    from displayio import Palette, Bitmap
+    from .displayio_types import PaletteConstructor, BitmapConstructor
+except ImportError:
+    pass
+
 __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_ImageLoad.git"
 
 
-def load(file_or_filename, *, bitmap=None, palette=None):
+def load(
+    file_or_filename: Union[str, BufferedReader],
+    *,
+    bitmap: Optional[BitmapConstructor] = None,
+    palette: Optional[PaletteConstructor] = None
+) -> Tuple[Bitmap, Optional[Palette]]:
     """Load pixel values (indices or colors) into a bitmap and colors into a palette.
 
     bitmap is the desired type. It must take width, height and color_depth in the constructor. It
     must also have a _load_row method to load a row's worth of pixel data.
 
-    palette is the desired pallete type. The constructor should take the number of colors and
+    palette is the desired palette type. The constructor should take the number of colors and
     support assignment to indices via [].
     """
     if not bitmap or not palette:
